/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 * 
 * Contributor(s):
 * 
 * $Id: edir_xml.h,v 1.1.2.3.2.1 2000/10/19 17:59:07 jasona Exp $
 */
#ifndef __EDIR_XML_H__
#define __EDIR_XML_H__ 1
#ifdef __cplusplus
extern "C" {
#endif

/**
 * Enhydra Director SAX filter structure.
 * <P>
 * This structure contains bookkeeping information for a filter placed
 * on a SAX handler block.
 * 
 * @member oldsax The original SAX block.
 * @member sax    The new filter SAX block.
 * @member ctx    The original userData.
 * @member ctxt   Pointer to the current parse context.
 * @member data   ClientData pointer. (payload)
 * @member vctxt  Holder for saved validation context fields.
 */
typedef struct edir_conf_xml_sax_filter {
    xmlSAXHandlerPtr	oldsax;
    xmlSAXHandlerPtr	sax;
    void		*ctx;
    xmlParserCtxtPtr	ctxt;
    void		*data;
    xmlValidCtxt	vctxt;
} edir_conf_xml_sax_filter_t;

/**
 * Error handler data structure.
 * <P>
 * Holds a pointer to a string/data buffer.  This is NULL
 * until the first error is encountered.
 * 
 * @member sbuf Pointer to a string/data buffer object.
 */
typedef struct edir_conf_xml_errdata {
    void	*sbuf;
} edir_conf_xml_errdata_t;

extern void
edir_xml_sax_install_filter(xmlParserCtxtPtr ctxt, xmlSAXHandlerPtr filter,
			    void *clientData);

extern void
edir_xml_sax_remove_filter(xmlParserCtxtPtr ctxt);

extern edir_conf_xml_errdata_t *
edir_xml_set_error_filter(xmlParserCtxt *ctxt);

extern void
edir_xml_clear_error_filter(xmlParserCtxt *ctxt);

extern void
edir_xml_init();

#ifdef __cplusplus
} /* extern "C" */
#endif
#endif /* __EDIR_XML_H__ */

