#!/bin/sh 
#
# fixMakefiles.sh
#
# Run this script when 
# Changes the ROOT macro in makefiles
# to be relative to the application

DEBUG=/dev/null
#DEBUG=/tmp/fm.out

echo "## fixMakefiles $$ running in "`pwd` >> $DEBUG

# bail if no Enhydra app Makefile above us
MF=../Makefile
DD=..
while [ true ] 
do
    echo "### fixMakefiles MF=$MF" >> $DEBUG
    [ ! -f $MF ] && {
	echo "### fixMakefiles $$ exiting because no MF=$MF" >> $DEBUG
	exit
    }

    # Makefile may or may not directly include stdrules.mk
    inc_rem="#"
    grep -i '^include.*stdrules' $MF > /dev/null
    [ $? = 0 ] && inc_rem=""

    # Enhydra app Makefie will have ROOT set as relative path
    #ROOT=`grep 'ROOT =' $MF | head -1 | sed 's,.*=[ 	][ 	]*,,'`
    x=`grep 'ROOT =' $MF | head -1 | sed 's,=, ,'`
    set $x
    ROOTVAR=$1
    ROOT=$2
    echo "### fixMakefiles ROOT=$ROOT" >> $DEBUG
    echo $ROOT | grep '^\.\.' > /dev/null
    [ $? = 0 ] && break

    MF=../$MF
    DD=../$DD
done
echo "### fixMakefiles after LOOP" >> $DEBUG

# bail if no PACKAGEDIR in app Makefile
#APP_PKG=`grep 'PACKAGEDIR =' $MF | head -1 | sed -e 's,.*= ,,' -e 's,/,.,g'`
#[ "$APP_PKG" = '' ] && {
    #echo "### fixMakefiles $$ exiting because empty APP_PKG=$APP_PKG" >> $DEBUG
    #exit
#}
#echo "### fixMakefiles $$ APP_PKG=$APP_PKG" >> $DEBUG

# bail if any generated classes are not in package $APP_PKG.data
#grep -v "^package $APP_PKG.data" *.java > /dev/null
#[ $? = 0 ] && {
    #echo "### fixMakefiles $$ exiting because no matching package stmt" >> $DEBUG
    #exit
#}

sources=`echo *.java`
  
if [ "$sources" = '*.java' ]; then
    PKG=no_java
else
    # grep for 'package...;' in the .java files in this directory.
    # They should all be in the same package, so we just grab the first one.
    # Strip off the word 'package' and the semicolon.
    PKG=`grep "^package " *.java | sed -e 's,.*package\(.*\);,\1,' | head -1`
    [ "$PKG" = "" ] && PKG=no_java
fi

# return relative ROOT and PKG
echo "### fixMakefiles $$ returning $DD/$ROOT $PKG" >> $DEBUG
echo $ROOTVAR $DD/$ROOT $PKG "$inc_rem"
